﻿//
// Copyright (c) 2011, MindFusion LLC - Bulgaria.
//


using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace Sales
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        List<Brush> scatterFills;
        List<Brush> scatterStrokes;
        List<ScatterType> scatterTypes;
        

        SalesList sales;
        public Window1()
        {
            sales = new SalesList();
            InitializeScatterSettings();

            InitializeComponent();
            lineChart1.YAxes[0].Interval = 100L;
            lineChart1.YAxes[0].TitleOffset = 10.0;
            lineChart1.YAxes[0].Title = "USD";

            lineChart1.XAxes[0].MaxValue = sales.Count + 1;
            lineChart1.XAxes[0].Tick = 5.0;
            lineChart1.XAxes[0].LabelPath = "Month";
            lineChart1.XAxes[0].LabelType = LabelType.CustomText;
            //lineChart1.XAxes[0].Labels = new string[] { "w", "w", "w", "w", };
            lineChart1.DataSource = sales;           

            lineChart1.Series.Clear();
           //first series
            MindFusion.Charting.Wpf.LineSeries lSeries1 = new MindFusion.Charting.Wpf.LineSeries()
            {
                Effect = new DropShadowEffect() { ShadowDepth = 3, Opacity = 0.7 },
            };
            lSeries1.YDataPath = "Turnover";
            lSeries1.Title = "Turnover";
            lSeries1.StrokeThickness = 2.0;     
            lSeries1.Strokes.Add(new SolidColorBrush(Colors.Red));
            lSeries1.Fills.Add(new SolidColorBrush(Colors.Red));
            lSeries1.ScatterStrokes.Add(new SolidColorBrush(Colors.Red));
            lSeries1.ScatterFills.Add(new SolidColorBrush(Colors.Red));
            lSeries1.LabelFontFamily = new FontFamily("Verdana");
            lineChart1.Series.Add(lSeries1);

            //second series
            MindFusion.Charting.Wpf.LineSeries lSeries2 = new MindFusion.Charting.Wpf.LineSeries()
            {
                Effect = new DropShadowEffect() {ShadowDepth = 3, Opacity = 0.7 },
            };
            lSeries2.YDataPath = "Profit";
            lSeries2.Title = "Profit";       
            lSeries2.Strokes.Add(new SolidColorBrush(Colors.Green));
            lSeries2.Fills.Add(new SolidColorBrush(Colors.Green));
            lSeries2.ScatterStrokes.Add(new SolidColorBrush(Colors.Green));
            lSeries2.ScatterFills.Add(new SolidColorBrush(Colors.Green));
            lSeries2.StrokeThickness = 2.0;
            lSeries2.LabelFontFamily = new FontFamily("Verdana");
            lineChart1.Series.Add(lSeries2);

            for (int i = 0; i < sales.Count; i++)
            {
                lSeries1.XData.Add(i + 1);
                lSeries2.XData.Add(i + 1);
            }

            MindFusion.Charting.Wpf.ChartLegend legend = new MindFusion.Charting.Wpf.ChartLegend();
            legend.Series = lineChart1.Series;
            legend.BorderBrush = lineChart1.BorderBrush;
            legend.BorderThickness = new Thickness(1);
            legend.Background = new SolidColorBrush(Color.FromRgb(250, 250, 250));
            MindFusion.Charting.Wpf.LayoutPanel.SetDock(legend, Dock.Right);
            legend.VerticalAlignment = VerticalAlignment.Top;
            legend.CornerRadius = new CornerRadius(5);
            legend.Margin = new Thickness(5);            
            lineChart1.Legends.Add(legend);

            cbLineType.Items.Add("Area2D");
            cbLineType.Items.Add("Area2DStack");
            cbLineType.Items.Add("Line");
            cbLineType.Items.Add("Scatter"); 
        }

        private void InitializeScatterSettings()
        {
            scatterFills = new List<Brush>(2);
            scatterFills.Add(Brushes.Pink);
            scatterFills.Add(Brushes.LightGreen);

            scatterStrokes = new List<Brush>(2);
            scatterStrokes.Add(Brushes.Red);
            scatterStrokes.Add(Brushes.Green);

            scatterTypes = new List<ScatterType>(2);
            scatterTypes.Add(ScatterType.Triangle);
            scatterTypes.Add(ScatterType.Diamond);
        }

        private void cbLineType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {          

            foreach (MindFusion.Charting.Wpf.LineSeries series in lineChart1.Series)
            {

                switch (cbLineType.SelectedIndex)
                {
                    case 0:
                        {
                            lineChart1.LineType = MindFusion.Charting.Wpf.LineType.Area2D;
                            break;
                        }
                    case 1:
                        {
                            lineChart1.LineType = MindFusion.Charting.Wpf.LineType.Area2DStack;
                            break;
                        }
                    case 2:
                        {
                            lineChart1.LineType = MindFusion.Charting.Wpf.LineType.Line;
                            break;
                        }
                    case 3:
                        {
                            lineChart1.LineType = LineType.None;
                            cbScatter.IsChecked = true;
                            break;
                        }
                }
                           
            }

            lineChart1.UpdateChart();

        }


        private void addScatter(int index)
        {
            LineSeries series = lineChart1.Series[index] as LineSeries;
            series.ScatterType = scatterTypes[index];
            series.ScatterSize = 13.0;
            //series.ScatterStrokes.Add(scatterStrokes[index]);
            series.ScatterStrokeThickness = 1.0;
            //series.ScatterFills.Add(scatterFills[index]);
        }

        private void removeScatter(int index)
        {
            LineSeries series = lineChart1.Series[index] as LineSeries;
            series.ScatterType = ScatterType.None;
        }

        private void cbScatter_Checked(object sender, RoutedEventArgs e)
        {
            for (int i = 0; i < lineChart1.Series.Count; i++)
                addScatter(i);

            lineChart1.UpdateChart();
        }

        private void cbScatter_Unchecked(object sender, RoutedEventArgs e)
        {
            for (int i = 0; i < lineChart1.Series.Count; i++)
                removeScatter(i);

            lineChart1.UpdateChart();
        }

        private void cbLabels_Checked(object sender, RoutedEventArgs e)
        {
            if (lineChart1.Series.Count >= 2)
            {
                (lineChart1.Series[0] as LineSeries).LabelPath = "Turnover";
                (lineChart1.Series[1] as LineSeries).LabelPath = "Profit";                
            }            
        }
        private void cbLabels_Unchecked(object sender, RoutedEventArgs e)
        {
            foreach (LineSeries series in lineChart1.Series)           
                series.LabelPath = "";           
        }

        private void cbCurve_Checked(object sender, RoutedEventArgs e)
        {
            foreach (ChartSeries s in lineChart1.Series)
            {
                if (s is LineSeries)
                    (s as LineSeries).Curve = true;
            }
        }

        private void cbCurve_Unchecked(object sender, RoutedEventArgs e)
        {
            foreach (ChartSeries s in lineChart1.Series)
            {
                if (s is LineSeries)
                    (s as LineSeries).Curve = false;
            }
        }        
    }
}
